@@ -16,8 +16,12 @@ use constant _DUMP_PP => scalar($DEBUG =~ /\b dump=pp \b/xms);
 
 no warnings 'recursion';
 
-our @CARP_NOT = qw(Text::Xslate);
-
+require Text::Xslate::PP;
+if(!Text::Xslate::PP::_PP_ERROR_VERBOSE()) {
+    our @CARP_NOT = qw(
+        Text::Xslate
+    );
+}
 our $_current_frame;
 
 
@@ -160,7 +164,7 @@ sub op_print_raw_s {
 
 
 sub op_include {
-    my $st = Text::Xslate::PP::tx_load_template( $_[0]->engine, $_[0]->{sa} );
+    my $st = Text::Xslate::PP::tx_load_template( $_[0]->engine, $_[0]->{sa}, 1 );
     $_[0]->{ output } .= Text::Xslate::PP::tx_execute( $st, $_[0]->{vars} );
 
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
@@ -241,8 +245,17 @@ sub op_div {
 
 
 sub op_mod {
-    $_[0]->{sa} = $_[0]->{sb} % $_[0]->{sa};
-    goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
+    my($st) = @_;
+    my $lhs = int $st->{sb};
+    my $rhs = int $st->{sa};
+    if($rhs == 0) {
+        $st->error(undef, "Illegal modulus zero");
+        $st->{sa} = 'NaN';
+    }
+    else {
+        $st->{sa} = $lhs % $rhs;
+    }
+    goto $st->{ code }->[ ++$st->{ pc } ]->{ exec_code };
 }
 
 
@@ -252,6 +265,12 @@ sub op_concat {
     goto $st->{ code }->[ ++$st->{ pc } ]->{ exec_code };
 }
 
+sub op_repeat {
+    my($st) = @_;
+    $st->{sa} = Text::Xslate::PP::tx_repeat($st->{sb}, $st->{sa});
+    goto $st->{ code }->[ ++$st->{ pc } ]->{ exec_code };
+}
+
 sub op_bitor {
     $_[0]->{sa} = int($_[0]->{sb}) | int($_[0]->{sa});
     goto $_[0]->{ code }->[ ++$_[0]->{ pc } ]->{ exec_code };
